#!/bin/bash
# Copyright (C) 2011, 2013-2014 Luke Shumaker <lukeshu@sbcglobal.net>

# Usage: hangman-helper word not [-l]
# <word> is the known word, with unknown characters replaced with '.'.
# <not> is a sequence of the characters that are known to not be in the word.
#
# Without the `-l` flag, it produces a list of possible completions.
#
# With the `-l` flag, it produces a list of letters,
# sorted by the number of times they appear in the normal list

word=$1
not=$2
flag=$3

temp="$(mktemp --tmpdir "${0##*/}.XXXXXXXXXX")"
trap "rm -f -- $(printf '%q' "$temp")" EXIT

grep -ix "$word" /usr/share/dict/words | grep -iv "['$not]" > "$temp"

if [[ "$flag" = '-l' ]]; then
	cat "$temp" | tr 'A-Z' 'a-z' | sed 's/\(.\)/\1\n/'g | sort | uniq -c | sort -n
else
	cat "$temp"
fi
